<?php

namespace Litecms\Member\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Member\Http\Requests\MemberRequest;
use Litecms\Member\Models\Member;

/**
 * Admin web controller class.
 */
class MemberWorkflowController extends BaseController
{

    /**
     * Workflow controller function for member.
     *
     * @param Model   $member
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(MemberRequest $request, Member $member, $step)
    {

        try {

            $member->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('member::member.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/member/member/' . $member->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/member/member/' . $member->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for member.
     *
     * @param Model   $member
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Member $member, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $member->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('member::member.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('member::admin.member.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('member::admin.member.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('member::admin.member.message', $data)->render();

        }

    }
}
