<?php

namespace Litecms\Member\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\Member\Models\Member;

class MemberAction
{
    /**
     * Perform the complete action.
     *
     * @param Member $member
     *
     * @return Member
     */
    public function complete(Member $member)
    {
        try {
            $member->status = 'complete';
            return $member->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Member $member
     *
     * @return Member
     */public function verify(Member $member)
    {
        try {
            $member->status = 'verify';
            return $member->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Member $member
     *
     * @return Member
     */public function approve(Member $member)
    {
        try {
            $member->status = 'approve';
            return $member->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Member $member
     *
     * @return Member
     */public function publish(Member $member)
    {
        try {
            $member->status = 'publish';
            return $member->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Member $member
     *
     * @return Member
     */
    public function archive(Member $member)
    {
        try {
            $member->status = 'archive';
            return $member->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Member $member
     *
     * @return Member
     */
    public function unpublish(Member $member)
    {
        try {
            $member->status = 'unpublish';
            return $member->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
