<?php

namespace Litecms\Member\Workflow;

use Litecms\Member\Models\Member;
use Validator;

class MemberValidator
{

    /**
     * Determine if the given member is valid for complete status.
     *
     * @param Member $member
     *
     * @return bool / Validator
     */
    public function complete(Member $member)
    {
        return Validator::make($member->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given member is valid for verify status.
     *
     * @param Member $member
     *
     * @return bool / Validator
     */
    public function verify(Member $member)
    {
        return Validator::make($member->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given member is valid for approve status.
     *
     * @param Member $member
     *
     * @return bool / Validator
     */
    public function approve(Member $member)
    {
        return Validator::make($member->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given member is valid for publish status.
     *
     * @param Member $member
     *
     * @return bool / Validator
     */
    public function publish(Member $member)
    {
        return Validator::make($member->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given member is valid for archive status.
     *
     * @param Member $member
     *
     * @return bool / Validator
     */
    public function archive(Member $member)
    {
        return Validator::make($member->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given member is valid for unpublish status.
     *
     * @param Member $member
     *
     * @return bool / Validator
     */
    public function unpublish(Member $member)
    {
        return Validator::make($member->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
